@@ -3,7 +3,7 @@ from policyengine_core.errors import (
     ParameterParsingError,
 )
 
-
+from .at_instant_like import AtInstantLike
 from .config import (
     ALLOWED_PARAM_TYPES,
     COMMON_KEYS,
@@ -11,26 +11,20 @@ from .config import (
     date_constructor,
     dict_no_duplicate_constructor,
 )
-
-from .at_instant_like import AtInstantLike
 from .helpers import contains_nan, load_parameter_file
-from .parameter_at_instant import ParameterAtInstant
-from .parameter_node_at_instant import ParameterNodeAtInstant
-from .vectorial_parameter_node_at_instant import (
-    VectorialParameterNodeAtInstant,
-)
-from .parameter import Parameter
-from .parameter_node import ParameterNode
-from .parameter_scale import (
-    ParameterScale,
-)
-from .parameter_scale_bracket import (
-    ParameterScaleBracket,
-)
-
 from .operations import (
     homogenize_parameter_structures,
     interpolate_parameters,
     propagate_parameter_metadata,
     uprate_parameters,
+    get_parameter,
+)
+from .parameter import Parameter
+from .parameter_at_instant import ParameterAtInstant
+from .parameter_node import ParameterNode
+from .parameter_node_at_instant import ParameterNodeAtInstant
+from .parameter_scale import ParameterScale
+from .parameter_scale_bracket import ParameterScaleBracket
+from .vectorial_parameter_node_at_instant import (
+    VectorialParameterNodeAtInstant,
 )
