@@ -98,7 +98,7 @@ class Simulation:
         self.tracer: SimpleTracer = SimpleTracer()
         self.opt_out_cache: bool = False
         # controls the spirals detection; check for performance impact if > 1
-        self.max_spiral_loops: int = 1
+        self.max_spiral_loops: int = 10
         self.memory_config: MemoryConfig = None
         self._data_storage_dir: str = None
 
@@ -293,6 +293,7 @@ class Simulation:
         variable_name: str,
         period: Period = None,
         map_to: str = None,
+        decode_enums: bool = False,
     ) -> ArrayLike:
         """Calculate ``variable_name`` for ``period``.
 
@@ -300,6 +301,7 @@ class Simulation:
             variable_name (str): The name of the variable to calculate.
             period (Period): The period to calculate the variable for.
             map_to (str): The name of the variable to map the result to. If None, the result is returned as is.
+            decode_enums (bool): If True, the result is decoded from an array of integers to an array of strings.
 
         Returns:
             ArrayLike: The calculated variable.
@@ -316,6 +318,8 @@ class Simulation:
 
         try:
             result = self._calculate(variable_name, period)
+            if isinstance(result, EnumArray) and decode_enums:
+                result = result.decode_to_str()
             self.tracer.record_calculation_result(result)
             if map_to is not None:
                 source_entity = self.tax_benefit_system.get_variable(
@@ -471,7 +475,8 @@ class Simulation:
                 known_periods = holder.get_known_periods()
                 if variable.uprating is not None and len(known_periods) > 0:
                     start_instants = [
-                        known_period.start for known_period in known_periods
+                        str(known_period.start)
+                        for known_period in known_periods
                     ]
                     latest_known_period = known_periods[
                         np.argmax(start_instants)
@@ -493,7 +498,8 @@ class Simulation:
                         uprating_factor = (
                             value_in_this_period / value_in_last_period
                         )
-                        return (
+
+                        array = (
                             holder.get_array(
                                 latest_known_period, self.branch_name
                             )
@@ -544,7 +550,10 @@ class Simulation:
         self.invalidated_caches = set()
 
     def calculate_add(
-        self, variable_name: str, period: Period = None
+        self,
+        variable_name: str,
+        period: Period = None,
+        decode_enums: bool = False,
     ) -> ArrayLike:
         variable = self.tax_benefit_system.get_variable(
             variable_name, check_existence=True
@@ -580,7 +589,10 @@ class Simulation:
         )
 
     def calculate_divide(
-        self, variable_name: str, period: Period = None
+        self,
+        variable_name: str,
+        period: Period = None,
+        decode_enums: bool = False,
     ) -> ArrayLike:
         variable = self.tax_benefit_system.get_variable(
             variable_name, check_existence=True
