@@ -3,9 +3,9 @@ import inspect
 import re
 import textwrap
 from typing import Callable, List, Type
-import sortedcontainers
 
 import numpy
+import sortedcontainers
 
 from policyengine_core import periods, tools
 from policyengine_core.entities import Entity
@@ -20,6 +20,21 @@ class QuantityType:
     FLOW = "flow"
 
 
+class VariableStage:
+    INPUT = "input"
+    INTERMEDIATE = "intermediate"
+    OUTPUT = "output"
+
+
+class VariableCategory:
+    TAX = "tax"
+    BENEFIT = "benefit"
+    INCOME = "income"
+    CONSUMPTION = "consumption"
+    WEALTH = "wealth"
+    DEMOGRAPHIC = "demographic"
+
+
 class Variable:
     """
     A `variable <https://openfisca.org/doc/key-concepts/variables.html>`_ of the legislation.
@@ -34,7 +49,7 @@ class Variable:
     entity: Entity
     """`Entity <https://openfisca.org/doc/key-concepts/person,_entities,_role.html>`_ the variable is defined for. For instance : ``Person``, ``Household``."""
 
-    definition_period: Period
+    definition_period: str
     """`Period <https://openfisca.org/doc/coding-the-legislation/35_periods.html>`_ the variable is defined for. Possible value: ``MONTH``, ``YEAR``, ``ETERNITY``."""
 
     formulas: List[Callable]
@@ -82,9 +97,30 @@ class Variable:
     quantity_type: str
     """Categorical attribute describing whether the variable is a stock or a flow."""
 
-    defined_for: str
+    defined_for: str = None
     """The name of another variable, nonzero values of which are used to define the set of entities for which this variable is defined."""
 
+    metadata: dict = None
+    """Free dictionary field used to store any metadata."""
+
+    module_name: str = None
+    """The name of the module it is defined in."""
+
+    index_in_module: int = None
+    """Index of the variable in the module it is defined in."""
+
+    adds: List[str] = None
+    """List of variables that are added to the variable."""
+
+    subtracts: List[str] = None
+    """List of variables that are subtracted from the variable."""
+
+    uprating: str = None
+    """Name of a parameter used to uprate the variable."""
+
+    hidden_input: bool = False
+    """Whether the variable is hidden from the input screen entirely on PolicyEngine."""
+
     def __init__(self, baseline_variable=None):
         self.name = self.__class__.__name__
         attr = {
@@ -175,7 +211,37 @@ class Variable:
             ],
         )
 
-        self.defined_for = self.set(attr, "defined_for", allowed_type=None)
+        self.defined_for = self.set_defined_for(attr.pop("defined_for", None))
+
+        self.metadata = self.set(attr, "metadata", allowed_type=dict)
+
+        self.category = self.set(
+            attr,
+            "category",
+            allowed_type=str,
+            default=None,
+        )
+
+        self.module_name = self.set(
+            attr,
+            "module_name",
+            allowed_type=str,
+            default=None,
+        )
+
+        self.index_in_module = self.set(
+            attr,
+            "index_in_module",
+            allowed_type=int,
+            default=None,
+        )
+
+        self.adds = self.set(attr, "adds", allowed_type=list)
+        self.subtracts = self.set(attr, "subtracts", allowed_type=list)
+        self.uprating = self.set(attr, "uprating", allowed_type=str)
+        self.hidden_input = self.set(
+            attr, "hidden_input", allowed_type=bool, default=False
+        )
 
         formulas_attr, unexpected_attrs = helpers._partition(
             attr,
@@ -330,6 +396,11 @@ class Variable:
 
         return formulas
 
+    def set_defined_for(self, defined_for):
+        if isinstance(defined_for, Enum):
+            defined_for = defined_for.value
+        return defined_for
+
     def parse_formula_name(self, attribute_name):
         """
         Returns the starting date of a formula based on its name.
@@ -372,7 +443,9 @@ class Variable:
         """
         Returns True if the variable is an input variable.
         """
-        return len(self.formulas) == 0
+        no_specified_formulas = len(self.formulas) == 0
+        no_adds_or_subtracts = self.adds is None and self.subtracts is None
+        return no_specified_formulas and no_adds_or_subtracts
 
     @classmethod
     def get_introspection_data(cls, tax_benefit_system):
